/**
 * Copyright (c) 2005, Paul Tuckey
 * All rights reserved.
 * ====================================================================
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * ====================================================================
 */
package org.tuckey.web.filters.validation;

import junit.framework.TestCase;

/**
 *
 *
 */
public class ServerNameMatcherTest extends TestCase {

    public void testBasic() {
        ServerNameMatcher serverNameMatcher = new ServerNameMatcher("aaa, bbb,ccc   , ddd,");
        assertTrue(serverNameMatcher.isMatch("aaa"));
        assertTrue(serverNameMatcher.isMatch("bbb"));
        assertFalse(serverNameMatcher.isMatch("www"));
        assertTrue(serverNameMatcher.isMatch("Aaa"));
    }

    public void testWildcard() {
        ServerNameMatcher serverNameMatcher = new ServerNameMatcher(",,, ,*.aaa, bb*b, " +
                "qqq*.co.nz , " +
                "*.server.*.com.lx   ," +
                " *.dev.company.com");
        assertTrue(serverNameMatcher.isMatch("qqq.err.sss.aaa"));
        assertTrue(serverNameMatcher.isMatch("bbwwwwwwb"));
        assertFalse(serverNameMatcher.isMatch("bbcca"));
        assertTrue(serverNameMatcher.isMatch("qqqClient.co.nz"));
        assertTrue(serverNameMatcher.isMatch(" bob.seRver.us.com.lx  "));
        assertFalse(serverNameMatcher.isMatch(" bob.ZseRver.us.com.lx  "));
        assertTrue(serverNameMatcher.isMatch("bob.dev.company.com"));
        assertFalse(serverNameMatcher.isMatch("bob.test.company.com"));
        assertFalse(serverNameMatcher.isMatch("www.company.com"));
    }



}
