/**
 * Copyright (c) 2005, Paul Tuckey
 * All rights reserved.
 * ====================================================================
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * ====================================================================
 */
package org.tuckey.web.filters.validation;

import junit.framework.Test;
import junit.framework.TestSuite;
import org.apache.cactus.FilterTestCase;
import org.apache.cactus.WebRequest;
import org.apache.cactus.WebResponse;
import org.tuckey.web.filters.validation.utils.Log;

import javax.servlet.ServletException;
import java.io.IOException;

/**
 * @author Paul Tuckey
 * @version $Revision: 1 $ $Date: 2006-07-12 08:07:49 +1200 (Wed, 12 Jul 2006) $
 */
public class ValidationFilterTest extends FilterTestCase {

    private ValidationFilter filter;

    public void setUp() throws ServletException {
        Log.setLevel("systout:TRACE");

        config.setInitParameter("excludes", "/excluded, ^.*anotherex.*$");

        filter = new ValidationFilter();
        filter.init(config);
        Log.setLevel("sysout:TRACE");
    }

    public void tearDown() {
        filter.destroy();
        filter = null;
    }


    public static Test suite() {
        return new TestSuite(ValidationFilterTest.class);
    }

    public void beginNoParse(WebRequest theRequest) {
        theRequest.setURL("localhost", "", "/no-parse-test.jsp", null, null);
    }

    public void testNoParse() throws ServletException, IOException {
        filter.doFilter(request, response, filterChain);
    }

    public void endNoParse(WebResponse theResponse) {
        System.out.println(theResponse.getText());
        assertTrue("check doc didn't parse", theResponse.getText().indexOf("ValidationFilter") != -1);
        assertTrue("check source shows", theResponse.getText().indexOf("parser version test") != -1);
    }

    public void beginExclude(WebRequest theRequest) {
        theRequest.setURL("localhost", "", "/excluded/index.jsp", null, null);
    }

    public void testExclude() throws ServletException, IOException {
        filter.doFilter(request, response, filterChain);
    }

    public void endExclude(WebResponse theResponse) {
        System.out.println(theResponse.getText());
        assertTrue("check doc displayed verbatim", theResponse.getText().indexOf("<htmla>") == 0);
    }

    public void beginValidParse(WebRequest theRequest) {
        theRequest.setURL("localhost", "", "/validation-test-good.html", null, null);
    }

    public void testValidParse() throws ServletException, IOException {
        filter.doFilter(request, response, filterChain);
    }

    public void endValidParse(WebResponse theResponse) {
        System.out.println(theResponse.getText());
        assertTrue("check doc did parse", theResponse.getText().indexOf("<title>Me valid doc</title>") != -1);
    }


    public void beginTestSpeed(WebRequest theRequest) {
        theRequest.setURL("localhost", "", "/validation-test-good.html", null, null);
    }

    public void testTestSpeed() throws ServletException, IOException {
        long timeStart = System.currentTimeMillis();
        Log.setLevel("WARN");
        for (int i = 0; i < 1; i++) {
            filter.doFilter(request, response, filterChain);
        }
        Log.setLevel("TRACE");
        long took = System.currentTimeMillis() - timeStart;
        System.out.println("took " + took / 1 + " per req");
        assertTrue(took < 100);
    }


}



